.. Database Objects
.. ================
.. 
.. .. automodule:: HydraServer.db.model
..     :members:

Web Objects (Complex Models)
============================

.. automodule:: HydraServer.soap_server.hydra_complexmodels
    :members:

API functions
=============

Projects
--------

.. automodule:: HydraServer.soap_server.project
   :members:

Networks (Inc nodes & links)
----------------------------

General remarks
***************

Generally speaking, a network consists of nodes and links. Each node can be
connected to other one or several nodes through one or several links. Each link
connects exactly two nodes. 

.. automodule:: HydraServer.soap_server.network
   :members:

Attributes
----------

.. automodule:: HydraServer.soap_server.attributes
   :members:

Scenarios
---------

.. automodule:: HydraServer.soap_server.scenario
   :members:

User Management
---------------

.. automodule:: HydraServer.soap_server.users
   :members:

Plugins
-------

.. automodule:: HydraServer.soap_server.plugins
   :members:

Resource Templates
------------------

.. automodule:: HydraServer.soap_server.template
   :members:

Units and Dimensions
--------------------

.. automodule:: HydraServer.soap_server.units
   :members:

Static Files
------------

.. automodule:: HydraServer.soap_server.static
   :members:
